@@ -13,11 +13,11 @@
 
 from __future__ import annotations
 
+import os
 from enum import Enum
 from typing import List, Optional, Union
 
-import boto3
-from botocore.config import Config
+from botocore.errorfactory import ClientError
 from networkx import Graph, complete_graph, from_edgelist
 
 from braket.annealing.problem import Problem
@@ -79,7 +79,7 @@ class AwsDevice(Device):
     def run(
         self,
         task_specification: Union[Circuit, Problem],
-        s3_destination_folder: AwsSession.S3DestinationFolder,
+        s3_destination_folder: Optional[AwsSession.S3DestinationFolder] = None,
         shots: Optional[int] = None,
         poll_timeout_seconds: float = AwsQuantumTask.DEFAULT_RESULTS_POLL_TIMEOUT,
         poll_interval_seconds: float = AwsQuantumTask.DEFAULT_RESULTS_POLL_INTERVAL,
@@ -93,7 +93,10 @@ class AwsDevice(Device):
         Args:
             task_specification (Union[Circuit, Problem]): Specification of task
                 (circuit or annealing problem) to run on device.
-            s3_destination_folder: The S3 location to save the task's results to.
+            s3_destination_folder (AwsSession.S3DestinationFolder, optional): The S3 location to
+                save the task's results to. Default is `<default_bucket>/tasks` if evoked
+                outside of a Braket Job, `<Job Bucket>/jobs/<job name>/tasks` if evoked inside of
+                a Braket Job.
             shots (int, optional): The number of times to run the circuit or annealing problem.
                 Default is 1000 for QPUs and 0 for simulators.
             poll_timeout_seconds (float): The polling timeout for `AwsQuantumTask.result()`,
@@ -141,7 +144,13 @@ class AwsDevice(Device):
             self._aws_session,
             self._arn,
             task_specification,
-            s3_destination_folder,
+            s3_destination_folder
+            or (
+                AwsSession.parse_s3_uri(os.environ.get("AMZN_BRAKET_TASK_RESULTS_S3_URI"))
+                if "AMZN_BRAKET_TASK_RESULTS_S3_URI" in os.environ
+                else None
+            )
+            or (self._aws_session.default_bucket(), "tasks"),
             shots if shots is not None else self._default_shots,
             poll_timeout_seconds=poll_timeout_seconds,
             poll_interval_seconds=poll_interval_seconds,
@@ -152,7 +161,7 @@ class AwsDevice(Device):
     def run_batch(
         self,
         task_specifications: List[Union[Circuit, Problem]],
-        s3_destination_folder: AwsSession.S3DestinationFolder,
+        s3_destination_folder: Optional[AwsSession.S3DestinationFolder] = None,
         shots: Optional[int] = None,
         max_parallel: Optional[int] = None,
         max_connections: int = AwsQuantumTaskBatch.MAX_CONNECTIONS_DEFAULT,
@@ -166,7 +175,10 @@ class AwsDevice(Device):
         Args:
             task_specifications (List[Union[Circuit, Problem]]): List of  circuits
                 or annealing problems to run on device.
-            s3_destination_folder: The S3 location to save the tasks' results to.
+            s3_destination_folder (AwsSession.S3DestinationFolder, optional): The S3 location to
+                save the tasks' results to. Default is `<default_bucket>/tasks` if evoked
+                outside of a Braket Job, `<Job Bucket>/jobs/<job name>/tasks` if evoked inside of
+                a Braket Job.
             shots (int, optional): The number of times to run the circuit or annealing problem.
                 Default is 1000 for QPUs and 0 for simulators.
             max_parallel (int, optional): The maximum number of tasks to run on AWS in parallel.
@@ -190,10 +202,16 @@ class AwsDevice(Device):
             `braket.aws.aws_quantum_task_batch.AwsQuantumTaskBatch`
         """
         return AwsQuantumTaskBatch(
-            AwsDevice._copy_aws_session(self._aws_session, max_connections=max_connections),
+            AwsSession.copy_session(self._aws_session, max_connections=max_connections),
             self._arn,
             task_specifications,
-            s3_destination_folder,
+            s3_destination_folder
+            or (
+                AwsSession.parse_s3_uri(os.environ.get("AMZN_BRAKET_TASK_RESULTS_S3_URI"))
+                if "AMZN_BRAKET_TASK_RESULTS_S3_URI" in os.environ
+                else None
+            )
+            or (self._aws_session.default_bucket(), "tasks"),
             shots if shots is not None else self._default_shots,
             max_parallel=max_parallel if max_parallel is not None else self._default_max_parallel,
             max_workers=max_connections,
@@ -210,22 +228,26 @@ class AwsDevice(Device):
         self._populate_properties(self._aws_session)
 
     def _get_session_and_initialize(self, session):
-        current_region = session.boto_session.region_name
+        current_region = session.region
         try:
             self._populate_properties(session)
             return session
-        except Exception:
-            if "qpu" not in self._arn:
-                raise ValueError(f"Simulator {self._arn} not found in {current_region}")
+        except ClientError as e:
+            if e.response["Error"]["Code"] == "ResourceNotFoundException":
+                if "qpu" not in self._arn:
+                    raise ValueError(f"Simulator '{self._arn}' not found in '{current_region}'")
+            else:
+                raise e
         # Search remaining regions for QPU
         for region in frozenset(AwsDevice.REGIONS) - {current_region}:
-            region_session = AwsDevice._copy_aws_session(session, region)
+            region_session = AwsSession.copy_session(session, region)
             try:
                 self._populate_properties(region_session)
                 return region_session
-            except Exception:
-                pass
-        raise ValueError(f"QPU {self._arn} not found")
+            except ClientError as e:
+                if e.response["Error"]["Code"] != "ResourceNotFoundException":
+                    raise e
+        raise ValueError(f"QPU '{self._arn}' not found")
 
     def _populate_properties(self, session):
         metadata = session.get_device(self._arn)
@@ -315,27 +337,6 @@ class AwsDevice(Device):
     def _default_max_parallel(self):
         return AwsDevice.DEFAULT_MAX_PARALLEL
 
-    @staticmethod
-    def _copy_aws_session(
-        aws_session: AwsSession,
-        region: Optional[str] = None,
-        max_connections: Optional[int] = None,
-    ) -> AwsSession:
-        config = Config(max_pool_connections=max_connections) if max_connections else None
-        session_region = aws_session.boto_session.region_name
-        new_region = region or session_region
-        creds = aws_session.boto_session.get_credentials()
-        if creds.method == "explicit":
-            boto_session = boto3.Session(
-                aws_access_key_id=creds.access_key,
-                aws_secret_access_key=creds.secret_key,
-                aws_session_token=creds.token,
-                region_name=new_region,
-            )
-        else:
-            boto_session = boto3.Session(region_name=new_region)
-        return AwsSession(boto_session=boto_session, config=config)
-
     def __repr__(self):
         return "Device('name': {}, 'arn': {})".format(self.name, self.arn)
 
@@ -397,7 +398,7 @@ class AwsDevice(Device):
             session_for_region = (
                 aws_session
                 if region == session_region
-                else AwsDevice._copy_aws_session(aws_session, region)
+                else AwsSession.copy_session(aws_session, region)
             )
             # Simulators are only instantiated in the same region as the AWS session
             types_for_region = sorted(
