@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,18 +11,19 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-# Execute initialization code in circuit module
-import braket.circuits.circuit as circuit  # noqa: F401
-
-# Execute initialization code in gates module
-import braket.circuits.gates as gates  # noqa: F401
-import braket.circuits.noises as noises  # noqa: F401
-import braket.circuits.observables as observables  # noqa: F401
-import braket.circuits.result_types as result_types  # noqa: F401
+from braket.circuits import (  # noqa: F401
+    circuit,
+    compiler_directives,
+    gates,
+    noises,
+    observables,
+    result_types,
+)
 from braket.circuits.angled_gate import AngledGate  # noqa: F401
 from braket.circuits.ascii_circuit_diagram import AsciiCircuitDiagram  # noqa: F401
 from braket.circuits.circuit import Circuit  # noqa: F401
 from braket.circuits.circuit_diagram import CircuitDiagram  # noqa: F401
+from braket.circuits.compiler_directive import CompilerDirective  # noqa: F401
 from braket.circuits.gate import Gate  # noqa: F401
 from braket.circuits.instruction import Instruction  # noqa: F401
 from braket.circuits.moments import Moments, MomentsKey  # noqa: F401
